use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.19

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/Catalyst/Plugin/Static/File.pm',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/10-catalyst.t',
    't/20-psgi-mime.t',
    't/21-psgi-xsendfile.t',
    't/22-psgi-etag.t',
    't/23-psgi-conditional-get.t',
    't/lib/App.pm',
    't/lib/App/Controller/Root.pm',
    't/static/hello.txt'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
